=begin
#Webhooks API

#Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.

The version of the OpenAPI document: v3

Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.2.3

=end

require 'cgi'

module Hubspot
  module Webhooks
    class SubscriptionsApi
      attr_accessor :api_client

      def initialize(api_client = ApiClient.default)
        @api_client = api_client
      end
      # Delete a subscription
      # Permanently deletes a subscription. This cannot be undone.
      # @param subscription_id [Integer] The ID of subscription to delete.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @return [nil]
      def delete_subscription(subscription_id, app_id, opts = {})
        delete_subscription_with_http_info(subscription_id, app_id, opts)
        nil
      end

      # Delete a subscription
      # Permanently deletes a subscription. This cannot be undone.
      # @param subscription_id [Integer] The ID of subscription to delete.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
      def delete_subscription_with_http_info(subscription_id, app_id, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: SubscriptionsApi.delete_subscription ...'
        end
        # verify the required parameter 'subscription_id' is set
        if @api_client.config.client_side_validation && subscription_id.nil?
          fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscriptionsApi.delete_subscription"
        end
        # verify the required parameter 'app_id' is set
        if @api_client.config.client_side_validation && app_id.nil?
          fail ArgumentError, "Missing the required parameter 'app_id' when calling SubscriptionsApi.delete_subscription"
        end
        # resource path
        local_var_path = '/webhooks/v3/{appId}/subscriptions/{subscriptionId}'.sub('{' + 'subscriptionId' + '}', CGI.escape(subscription_id.to_s)).sub('{' + 'appId' + '}', CGI.escape(app_id.to_s))

        # query parameters
        query_params = opts[:query_params] || {}

        # header parameters
        header_params = opts[:header_params] || {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['*/*'])

        # form parameters
        form_params = opts[:form_params] || {}

        # http body (model)
        post_body = opts[:body] 

        # return_type
        return_type = opts[:return_type] 

        # auth_names
        auth_names = opts[:auth_names] || ['hapikey']

        new_options = opts.merge(
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => return_type
        )

        data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: SubscriptionsApi#delete_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      # Get subscription
      # Returns details about a subscription.
      # @param app_id [Integer] The ID of the target app.
      # @param subscription_id [Integer] The ID of the target subscription.
      # @param [Hash] opts the optional parameters
      # @return [SubscriptionResponse]
      def get_subscription(app_id, subscription_id, opts = {})
        data, _status_code, _headers = get_subscription_with_http_info(app_id, subscription_id, opts)
        data
      end

      # Get subscription
      # Returns details about a subscription.
      # @param app_id [Integer] The ID of the target app.
      # @param subscription_id [Integer] The ID of the target subscription.
      # @param [Hash] opts the optional parameters
      # @return [Array<(SubscriptionResponse, Integer, Hash)>] SubscriptionResponse data, response status code and response headers
      def get_subscription_with_http_info(app_id, subscription_id, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: SubscriptionsApi.get_subscription ...'
        end
        # verify the required parameter 'app_id' is set
        if @api_client.config.client_side_validation && app_id.nil?
          fail ArgumentError, "Missing the required parameter 'app_id' when calling SubscriptionsApi.get_subscription"
        end
        # verify the required parameter 'subscription_id' is set
        if @api_client.config.client_side_validation && subscription_id.nil?
          fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscriptionsApi.get_subscription"
        end
        # resource path
        local_var_path = '/webhooks/v3/{appId}/subscriptions/{subscriptionId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'subscriptionId' + '}', CGI.escape(subscription_id.to_s))

        # query parameters
        query_params = opts[:query_params] || {}

        # header parameters
        header_params = opts[:header_params] || {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['application/json', '*/*'])

        # form parameters
        form_params = opts[:form_params] || {}

        # http body (model)
        post_body = opts[:body] 

        # return_type
        return_type = opts[:return_type] || 'SubscriptionResponse' 

        # auth_names
        auth_names = opts[:auth_names] || ['hapikey']

        new_options = opts.merge(
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => return_type
        )

        data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: SubscriptionsApi#get_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      # Get subscription details
      # Returns full details for all existing subscriptions for the given app.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @return [SubscriptionListResponse]
      def get_subscriptions(app_id, opts = {})
        data, _status_code, _headers = get_subscriptions_with_http_info(app_id, opts)
        data
      end

      # Get subscription details
      # Returns full details for all existing subscriptions for the given app.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @return [Array<(SubscriptionListResponse, Integer, Hash)>] SubscriptionListResponse data, response status code and response headers
      def get_subscriptions_with_http_info(app_id, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: SubscriptionsApi.get_subscriptions ...'
        end
        # verify the required parameter 'app_id' is set
        if @api_client.config.client_side_validation && app_id.nil?
          fail ArgumentError, "Missing the required parameter 'app_id' when calling SubscriptionsApi.get_subscriptions"
        end
        # resource path
        local_var_path = '/webhooks/v3/{appId}/subscriptions'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s))

        # query parameters
        query_params = opts[:query_params] || {}

        # header parameters
        header_params = opts[:header_params] || {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['application/json', '*/*'])

        # form parameters
        form_params = opts[:form_params] || {}

        # http body (model)
        post_body = opts[:body] 

        # return_type
        return_type = opts[:return_type] || 'SubscriptionListResponse' 

        # auth_names
        auth_names = opts[:auth_names] || ['hapikey']

        new_options = opts.merge(
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => return_type
        )

        data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: SubscriptionsApi#get_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      # Subscribe to an event
      # Creates a new webhook subscription for the given app. Each subscription in an app must be unique.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @option opts [SubscriptionCreateRequest] :subscription_create_request Details about the new subscription.
      # @return [SubscriptionResponse]
      def subscribe(app_id, opts = {})
        data, _status_code, _headers = subscribe_with_http_info(app_id, opts)
        data
      end

      # Subscribe to an event
      # Creates a new webhook subscription for the given app. Each subscription in an app must be unique.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @option opts [SubscriptionCreateRequest] :subscription_create_request Details about the new subscription.
      # @return [Array<(SubscriptionResponse, Integer, Hash)>] SubscriptionResponse data, response status code and response headers
      def subscribe_with_http_info(app_id, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: SubscriptionsApi.subscribe ...'
        end
        # verify the required parameter 'app_id' is set
        if @api_client.config.client_side_validation && app_id.nil?
          fail ArgumentError, "Missing the required parameter 'app_id' when calling SubscriptionsApi.subscribe"
        end
        # resource path
        local_var_path = '/webhooks/v3/{appId}/subscriptions'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s))

        # query parameters
        query_params = opts[:query_params] || {}

        # header parameters
        header_params = opts[:header_params] || {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['application/json', '*/*'])
        # HTTP header 'Content-Type'
        header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

        # form parameters
        form_params = opts[:form_params] || {}

        # http body (model)
        post_body = opts[:body] || @api_client.object_to_http_body(opts[:'subscription_create_request']) 

        # return_type
        return_type = opts[:return_type] || 'SubscriptionResponse' 

        # auth_names
        auth_names = opts[:auth_names] || ['hapikey']

        new_options = opts.merge(
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => return_type
        )

        data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: SubscriptionsApi#subscribe\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      # Update a subscription
      # Updates the details for an existing subscription.
      # @param subscription_id [Integer] The ID of the subscription to update.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @option opts [SubscriptionPatchRequest] :subscription_patch_request Updated details for the subscription.
      # @return [SubscriptionResponse]
      def update_subscription(subscription_id, app_id, opts = {})
        data, _status_code, _headers = update_subscription_with_http_info(subscription_id, app_id, opts)
        data
      end

      # Update a subscription
      # Updates the details for an existing subscription.
      # @param subscription_id [Integer] The ID of the subscription to update.
      # @param app_id [Integer] The ID of the target app.
      # @param [Hash] opts the optional parameters
      # @option opts [SubscriptionPatchRequest] :subscription_patch_request Updated details for the subscription.
      # @return [Array<(SubscriptionResponse, Integer, Hash)>] SubscriptionResponse data, response status code and response headers
      def update_subscription_with_http_info(subscription_id, app_id, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: SubscriptionsApi.update_subscription ...'
        end
        # verify the required parameter 'subscription_id' is set
        if @api_client.config.client_side_validation && subscription_id.nil?
          fail ArgumentError, "Missing the required parameter 'subscription_id' when calling SubscriptionsApi.update_subscription"
        end
        # verify the required parameter 'app_id' is set
        if @api_client.config.client_side_validation && app_id.nil?
          fail ArgumentError, "Missing the required parameter 'app_id' when calling SubscriptionsApi.update_subscription"
        end
        # resource path
        local_var_path = '/webhooks/v3/{appId}/subscriptions/{subscriptionId}'.sub('{' + 'subscriptionId' + '}', CGI.escape(subscription_id.to_s)).sub('{' + 'appId' + '}', CGI.escape(app_id.to_s))

        # query parameters
        query_params = opts[:query_params] || {}

        # header parameters
        header_params = opts[:header_params] || {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['application/json', '*/*'])
        # HTTP header 'Content-Type'
        header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

        # form parameters
        form_params = opts[:form_params] || {}

        # http body (model)
        post_body = opts[:body] || @api_client.object_to_http_body(opts[:'subscription_patch_request']) 

        # return_type
        return_type = opts[:return_type] || 'SubscriptionResponse' 

        # auth_names
        auth_names = opts[:auth_names] || ['hapikey']

        new_options = opts.merge(
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => return_type
        )

        data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: SubscriptionsApi#update_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end
    end
  end
end
